@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,11 +49,10 @@
 
 package com.openexchange.datatypes.genericonf.storage;
 
+import static com.openexchange.groupware.AbstractOXException.Category.CODE_ERROR;
 import com.openexchange.exceptions.OXErrorMessage;
 import com.openexchange.groupware.AbstractOXException.Category;
 
-import static com.openexchange.groupware.AbstractOXException.Category.*;
-
 /**
  * {@link GenericConfigStorageErrorMessage}
  *
@@ -61,22 +60,23 @@ import static com.openexchange.groupware.AbstractOXException.Category.*;
  *
  */
 public enum GenericConfigStorageErrorMessage implements OXErrorMessage {
-    SQLException(CODE_ERROR, 1, "","A SQL Error occurred: %s");
+    SQLException(CODE_ERROR, 1, "","A SQL Error occurred: %1$s"),
+    UnsupportedObjectType(CODE_ERROR, 2, "","Object type is not supported: %1$s");
 
     private Category category;
     private int errorCode;
     private String help;
     private String message;
-    
+
     public static final GenericConfigStorageExceptionFactory EXCEPTIONS = new GenericConfigStorageExceptionFactory();
-    
-    private GenericConfigStorageErrorMessage(Category category, int errorCode, String help, String message) {
+
+    private GenericConfigStorageErrorMessage(final Category category, final int errorCode, final String help, final String message) {
         this.category = category;
         this.errorCode = errorCode;
         this.help = help;
         this.message = message;
     }
-    
+
     public Category getCategory() {
         return category;
     }
@@ -92,12 +92,12 @@ public enum GenericConfigStorageErrorMessage implements OXErrorMessage {
     public String getMessage() {
         return message;
     }
-    
-    public void throwException(Object...args) throws GenericConfigStorageException {
+
+    public void throwException(final Object...args) throws GenericConfigStorageException {
         throw EXCEPTIONS.create(this, args);
     }
-    
-    public void throwException(Exception cause, Object...args) throws GenericConfigStorageException {
+
+    public void throwException(final Exception cause, final Object...args) throws GenericConfigStorageException {
         throw EXCEPTIONS.create(this, cause, args);
     }
 
