@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,42 +55,42 @@ import com.openexchange.datatypes.genericonf.WidgetSwitcher;
 
 /**
  * {@link FromSQL}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class FromSQL implements WidgetSwitcher {
 
     private SQLException exception;
 
-    public Object checkbox(Object[] args) {
-        ResultSet rs = (ResultSet) args[0];
-        String columnName = (String) args[1];
+    public Object checkbox(final Object[] args) {
+        final ResultSet rs = (ResultSet) args[0];
+        final String columnName = (String) args[1];
 
         try {
             return rs.getBoolean(columnName);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             this.exception = e;
             return null;
         }
     }
 
-    public Object input(Object... args) {
+    public Object input(final Object... args) {
         return string(args);
     }
 
-    private Object string(Object[] args) {
-        ResultSet rs = (ResultSet) args[0];
-        String columnName = (String) args[1];
+    private Object string(final Object[] args) {
+        final ResultSet rs = (ResultSet) args[0];
+        final String columnName = (String) args[1];
 
         try {
             return rs.getString(columnName);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             this.exception = e;
             return null;
         }
     }
 
-    public Object password(Object... args) {
+    public Object password(final Object... args) {
         return string(args);
     }
 
@@ -101,11 +101,15 @@ public class FromSQL implements WidgetSwitcher {
 
     }
 
-    public Object link(Object... args) {
+    public Object link(final Object... args) {
         return string(args);
     }
 
-    public Object text(Object... args) {
+    public Object text(final Object... args) {
+        return string(args);
+    }
+
+    public Object custom(final Object... args) {
         return string(args);
     }
 
