@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,45 +60,46 @@ import java.util.List;
 import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.database.DBPoolingException;
+import com.openexchange.database.provider.DBProvider;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigStorageErrorMessage;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigStorageException;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
 import com.openexchange.groupware.Types;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.impl.IDGenerator;
-import com.openexchange.groupware.tx.DBProvider;
-import com.openexchange.groupware.tx.TransactionException;
 
 /**
  * {@link MySQLGenericConfigurationStorage}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class MySQLGenericConfigurationStorage implements GenericConfigurationStorageService {
 
-    private static final Log LOG = LogFactory.getLog(MySQLGenericConfigurationStorage.class);
-    
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MySQLGenericConfigurationStorage.class));
+
     private DBProvider provider;
 
-    public void setDBProvider(DBProvider provider) {
+    public void setDBProvider(final DBProvider provider) {
         this.provider = provider;
     }
 
-    public int save(Context ctx, Map<String, Object> content) throws GenericConfigStorageException {
+    public int save(final Context ctx, final Map<String, Object> content) throws GenericConfigStorageException {
         return save(null, ctx, content);
     }
-    
-    public int save(Connection con, final Context ctx, final Map<String, Object> content) throws GenericConfigStorageException {
+
+    public int save(final Connection con, final Context ctx, final Map<String, Object> content) throws GenericConfigStorageException {
         return ((Integer) write(con, ctx, new TX() {
 
+            @Override
             public Object perform() throws SQLException {
-                Connection con = getConnection();
+                final Connection con = getConnection();
 
-                InsertIterator insertIterator = new InsertIterator();
+                final InsertIterator insertIterator = new InsertIterator();
                 insertIterator.prepareStatements(this);
-                
-                int id = IDGenerator.getId(ctx, Types.GENERIC_CONFIGURATION, con);
-                int cid = ctx.getContextId();
+
+                final int id = IDGenerator.getId(ctx, Types.GENERIC_CONFIGURATION, con);
+                final int cid = ctx.getContextId();
                 insertIterator.setIds(cid, id);
 
                 Tools.iterate(content, insertIterator);
@@ -110,58 +111,58 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
         })).intValue();
     }
 
-    private Object write(Connection con, Context ctx, TX tx) throws GenericConfigStorageException {
+    private Object write(final Connection con, final Context ctx, final TX tx) throws GenericConfigStorageException {
         Connection writeCon = con;
-        boolean connectionHandling = con == null;
+        final boolean connectionHandling = con == null;
         try {
             if(connectionHandling) {
                 writeCon = provider.getWriteConnection(ctx);
                 writeCon.setAutoCommit(false);
             }
             tx.setConnection(writeCon);
-            Object retval = tx.perform();
+            final Object retval = tx.perform();
             if(connectionHandling) {
                 writeCon.commit();
             }
             return retval;
-        } catch (SQLException x) {
+        } catch (final SQLException x) {
             try {
                 if(connectionHandling) {
                     writeCon.rollback();
                 }
-            } catch (SQLException e) {
+            } catch (final SQLException e) {
             }
             LOG.error(x.getMessage(), x);
             GenericConfigStorageErrorMessage.SQLException.throwException(x, x.getMessage());
             return null;
-        } catch (TransactionException e) {
+        } catch (final DBPoolingException e) {
             throw new GenericConfigStorageException(e);
         } finally {
             tx.close();
             if(connectionHandling) {
                 try {
                     writeCon.setAutoCommit(true);
-                } catch (SQLException e) {
+                } catch (final SQLException e) {
                 }
                 provider.releaseWriteConnection(ctx, writeCon);
             }
         }
     }
-    
-    public void fill(Context ctx, int id, Map<String, Object> content) throws GenericConfigStorageException {
+
+    public void fill(final Context ctx, final int id, final Map<String, Object> content) throws GenericConfigStorageException {
         fill(null, ctx, id, content);
     }
 
-    public void fill(Connection con, Context ctx, int id, Map<String, Object> content) throws GenericConfigStorageException {
+    public void fill(final Connection con, final Context ctx, final int id, final Map<String, Object> content) throws GenericConfigStorageException {
         Connection readCon = con;
-        boolean connectionHandling = con == null;
+        final boolean connectionHandling = con == null;
         try {
             if(connectionHandling) {
                 readCon = provider.getReadConnection(ctx);
             }
             loadValues(readCon, ctx, id, content, "genconf_attributes_strings");
             loadValues(readCon, ctx, id, content, "genconf_attributes_bools");
-        } catch (TransactionException e) {
+        } catch (final DBPoolingException e) {
             throw new GenericConfigStorageException(e);
         } finally {
             if(connectionHandling) {
@@ -170,7 +171,7 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
         }
     }
 
-    private void loadValues(Connection readCon, Context ctx, int id, Map<String, Object> content, String tablename) throws GenericConfigStorageException {
+    private void loadValues(final Connection readCon, final Context ctx, final int id, final Map<String, Object> content, final String tablename) throws GenericConfigStorageException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
 
@@ -181,48 +182,49 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
             stmt.setInt(2, id);
             rs = stmt.executeQuery();
             while (rs.next()) {
-                String name = rs.getString("name");
-                Object value = rs.getObject("value");
-                
+                final String name = rs.getString("name");
+                final Object value = rs.getObject("value");
+
                 content.put(name, value);
             }
-        } catch (SQLException x) {
+        } catch (final SQLException x) {
             GenericConfigStorageErrorMessage.SQLException.throwException(x, stmt.toString());
         } finally {
             if (stmt != null) {
                 try {
                     stmt.close();
-                } catch (SQLException x) {
+                } catch (final SQLException x) {
                 }
 
             }
             if (rs != null) {
                 try {
                     rs.close();
-                } catch (SQLException x) {
+                } catch (final SQLException x) {
                 }
             }
         }
     }
-    
-   
+
+
     public void update(final Context ctx, final int id, final Map<String, Object> content) throws GenericConfigStorageException {
         update(null, ctx, id, content);
     }
-    
-    public void update(Connection con, final Context ctx, final int id, final Map<String, Object> content) throws GenericConfigStorageException {
+
+    public void update(final Connection con, final Context ctx, final int id, final Map<String, Object> content) throws GenericConfigStorageException {
         final Map<String, Object> original = new HashMap<String, Object>();
         fill(con, ctx, id, original);
 
         write(con, ctx, new TX() {
 
+            @Override
             public Object perform() throws SQLException {
-                UpdateIterator updateIterator = new UpdateIterator();
+                final UpdateIterator updateIterator = new UpdateIterator();
                 try {
                     updateIterator.prepareStatements(this);
                     updateIterator.setIds(ctx.getContextId(), id);
                     updateIterator.setOriginal(original);
-                    
+
                     Tools.iterate(content, updateIterator);
                 } finally {
                     updateIterator.close();
@@ -238,8 +240,8 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
     public void delete(final Context ctx, final int id) throws GenericConfigStorageException {
         delete(null, ctx, id);
     }
-    
-    public void delete(Connection con, final Context ctx, final int id) throws GenericConfigStorageException {
+
+    public void delete(final Connection con, final Context ctx, final int id) throws GenericConfigStorageException {
 
         write(con, ctx, new TX() {
 
@@ -249,8 +251,8 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
                 clearTable("genconf_attributes_bools");
                 return null;
             }
-            
-            private void clearTable(String tablename) throws SQLException {
+
+            private void clearTable(final String tablename) throws SQLException {
                 PreparedStatement delete = null;
                 delete = prepare("DELETE FROM "+tablename+" WHERE cid = ? AND id = ?");
                 delete.setInt(1, ctx.getContextId());
@@ -263,7 +265,7 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
 
     }
 
-    public void delete(Connection con, final Context ctx) throws GenericConfigStorageException {
+    public void delete(final Connection con, final Context ctx) throws GenericConfigStorageException {
 
         write(con, ctx, new TX() {
 
@@ -273,8 +275,8 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
                 clearTable("genconf_attributes_bools");
                 return null;
             }
-            
-            private void clearTable(String tablename) throws SQLException {
+
+            private void clearTable(final String tablename) throws SQLException {
                 PreparedStatement delete = null;
                 delete = prepare("DELETE FROM "+tablename+" WHERE cid = ?");
                 delete.setInt(1, ctx.getContextId());
@@ -285,19 +287,19 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
 
     }
 
-    public List<Integer> search(Context ctx, Map<String, Object> query) throws GenericConfigStorageException {
+    public List<Integer> search(final Context ctx, final Map<String, Object> query) throws GenericConfigStorageException {
         return search(null, ctx, query);
     }
-    
-    public List<Integer> search(Connection con, Context ctx, Map<String, Object> query) throws GenericConfigStorageException {
-        boolean handleOwnConnections = con == null;
-            
-        LinkedList<Integer> list = new LinkedList<Integer>();
-        StringBuilder builder = new StringBuilder("SELECT DISTINCT p.id FROM ");
-        SearchIterator whereIterator = new SearchIterator();
+
+    public List<Integer> search(Connection con, final Context ctx, final Map<String, Object> query) throws GenericConfigStorageException {
+        final boolean handleOwnConnections = con == null;
+
+        final LinkedList<Integer> list = new LinkedList<Integer>();
+        final StringBuilder builder = new StringBuilder("SELECT DISTINCT p.id FROM ");
+        final SearchIterator whereIterator = new SearchIterator();
         Tools.iterate(query, whereIterator);
-        
-        
+
+
         builder.append(whereIterator.getFrom());
         builder.append(" WHERE ");
         builder.append("(");
@@ -313,27 +315,27 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
             stmt = con.prepareStatement(builder.toString());
             whereIterator.setReplacements(stmt);
             rs = stmt.executeQuery();
-            
+
             while(rs.next()) {
                 list.add(I(rs.getInt(1)));
             }
-            
-        } catch (TransactionException e) {
+
+        } catch (final DBPoolingException e) {
             throw new GenericConfigStorageException(e);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             GenericConfigStorageErrorMessage.SQLException.throwException(e, stmt.toString());
         } finally {
             if(stmt != null) {
                 try {
                     stmt.close();
-                } catch (SQLException x) {
+                } catch (final SQLException x) {
                     // Ignore
                 }
             }
             if(rs != null) {
                 try {
-                    rs.close(); 
-                } catch (SQLException x) {
+                    rs.close();
+                } catch (final SQLException x) {
                     // Ignore
                 }
             }
@@ -341,7 +343,7 @@ public class MySQLGenericConfigurationStorage implements GenericConfigurationSto
                 provider.releaseReadConnection(ctx, con);
             }
         }
-        
+
         return list;
     }
 
