@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,29 +53,36 @@ import com.openexchange.datatypes.genericonf.WidgetSwitcher;
 
 /**
  * {@link ToSQLType}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  */
 public class ToSQLType implements WidgetSwitcher {
 
-    public Object input(Object... args) {
+    public Object input(final Object... args) {
         return args[0];
     }
 
-    public Object password(Object... args) {
+    public Object password(final Object... args) {
         return args[0];
     }
 
-    public Object checkbox(Object...args) {
+    public Object checkbox(final Object...args) {
         return args[0];
     }
 
-    public Object link(Object... args) {
+    public Object link(final Object... args) {
         return args[0];
     }
 
-    public Object text(Object... args) {
+    public Object text(final Object... args) {
         return args[0];
     }
 
+    public Object custom(final Object... args) {
+        if(args[0] == null) {
+            return null;
+        }
+        return args[0].toString();
+    }
+
 }
