@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,14 +60,14 @@ import com.openexchange.datatypes.genericonf.IterationBreak;
  *
  */
 public class Tools {
-    public static <K, V> void iterate(Map<K, V> map, MapIterator<K, V> iterator) {
-        for(Map.Entry<K, V> entry : map.entrySet()) {
+    public static <K, V> void iterate(final Map<K, V> map, final MapIterator<K, V> iterator) {
+        for(final Map.Entry<K, V> entry : map.entrySet()) {
             try {
                 iterator.handle(entry.getKey(), entry.getValue());
-            } catch (IterationBreak br) {
+            } catch (final IterationBreak br) {
                 return;
             }
         }
-            
+
     }
 }
