@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,6 +53,7 @@ import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import com.openexchange.database.CreateTableService;
+import com.openexchange.database.osgiservice.WhiteboardDBProvider;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigStorageErrorMessage;
 import com.openexchange.datatypes.genericonf.storage.GenericConfigurationStorageService;
 import com.openexchange.datatypes.genericonf.storage.impl.ClearGenConfTables;
@@ -60,7 +61,6 @@ import com.openexchange.datatypes.genericonf.storage.impl.CreateGenConfTables;
 import com.openexchange.datatypes.genericonf.storage.impl.MySQLGenericConfigurationStorage;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.groupware.delete.DeleteListener;
-import com.openexchange.groupware.tx.osgi.WhiteboardDBProvider;
 
 public class Activator implements BundleActivator {
 
@@ -72,10 +72,10 @@ public class Activator implements BundleActivator {
 
     private ComponentRegistration componentRegistration;
 
-    public void start(BundleContext context) throws Exception {
+    public void start(final BundleContext context) throws Exception {
         componentRegistration = new ComponentRegistration(context, "com.openexchange.datatypes.genericonf.storage", "GCF", GenericConfigStorageErrorMessage.EXCEPTIONS);
-        
-        MySQLGenericConfigurationStorage mySQLGenericConfigurationStorage = new MySQLGenericConfigurationStorage();
+
+        final MySQLGenericConfigurationStorage mySQLGenericConfigurationStorage = new MySQLGenericConfigurationStorage();
         mySQLGenericConfigurationStorage.setDBProvider(new WhiteboardDBProvider(context));
         clearTablesServiceRegistration = context.registerService(DeleteListener.class.getName(), new ClearGenConfTables(), null);
         createTablesServiceRegistration = context.registerService(CreateTableService.class.getName(), new CreateGenConfTables(), null);
@@ -85,7 +85,7 @@ public class Activator implements BundleActivator {
             null);
     }
 
-    public void stop(BundleContext context) throws Exception{
+    public void stop(final BundleContext context) throws Exception{
         serviceRegistration.unregister();
         createTablesServiceRegistration.unregister();
         clearTablesServiceRegistration.unregister();
